@@ -9,41 +9,49 @@ build_time_vars = {'ABIFLAGS': '',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic',
+ 'BASECFLAGS': '-fno-common -dynamic',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/bin',
- 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
+ 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/bin',
+ 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11',
  'BLDLIBRARY': '',
  'BLDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup   -L/opt/local/lib -Wl,-headerpad_max_install_names  ',
+ 'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-apple-darwin14.5.0',
  'BYTESTR_DEPS': '\\',
  'CC': '/usr/bin/clang',
  'CCSHARED': '',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os  ',
+ 'CFLAGS': '-fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os  ',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '-fno-strict-aliasing',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'CONFIGURE_CFLAGS': '  -pipe -Os  ',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden',
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration -fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/opt/local/include',
  'CONFIGURE_LDFLAGS': '  -L/opt/local/lib -Wl,-headerpad_max_install_names  ',
  'CONFIGURE_LDFLAGS_NODIST': '',
+ 'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/opt/local' '--disable-dependency-tracking' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' '--with-ensurepip=no' '--with-readline=editline' '--with-system-expat' '--with-system-ffi' '--enable-universalsdk=/' '--enable-optimizations' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -Os  ' 'LDFLAGS=-L/opt/local/lib -Wl,-headerpad_max_install_names  ' 'CPPFLAGS=-I/opt/local/include'",
- 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include',
- 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10',
+ 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/include',
+ 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19/coverage.info',
- 'COVERAGE_REPORT': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19/lcov-report',
- 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
+ 'COVERAGE_INFO': '/opt/local/var/macports/build/python311-b83b7169/work/Python-3.11.14/coverage.info',
+ 'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
+ 'COVERAGE_REPORT': '/opt/local/var/macports/build/python311-b83b7169/work/Python-3.11.14/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage --title "CPython 3.11 LCOV report [commit $(shell )]"',
  'CPPFLAGS': '-I. -I./Include -I/opt/local/include',
  'CXX': '/usr/bin/clang++',
- 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10 /opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10 /opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/lib-dynload',
- 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
+ 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DUNIVERSAL=1',
+ 'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
+ 'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python ./Programs/_freeze_module.py \\',
+ 'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
+ 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11 /opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11 /opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11/lib-dynload',
+ 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/lib-dynload',
+ 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -63,20 +71,27 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
+ 'EXPAT_CFLAGS': '',
+ 'EXPAT_LDFLAGS': '-lexpat',
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-310-darwin.so',
+ 'EXT_SUFFIX': '.cpython-311-darwin.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
- 'FLOCK_NEEDS_LIBBSD': 0,
+ 'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
+ 'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
+ 'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
+ 'FREEZE_MODULE_DEPS': '_bootstrap_python ./Programs/_freeze_module.py',
+ 'FROZEN_FILES_IN': '\\',
+ 'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
  'GNULD': 'no',
+ 'HAVE_ACCEPT': 1,
  'HAVE_ACCEPT4': 0,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
@@ -87,6 +102,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 0,
  'HAVE_ATANH': 1,
+ 'HAVE_BIND': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
@@ -99,18 +115,21 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BROKEN_SEM_GETVALUE': 1,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_BUILTIN_ATOMIC': 1,
+ 'HAVE_BZLIB_H': 1,
  'HAVE_CHFLAGS': 1,
+ 'HAVE_CHMOD': 1,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
  'HAVE_CLOCK_GETRES': 0,
  'HAVE_CLOCK_GETTIME': 0,
+ 'HAVE_CLOCK_NANOSLEEP': 0,
  'HAVE_CLOCK_SETTIME': 0,
  'HAVE_CLOSE_RANGE': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
- 'HAVE_COPYSIGN': 1,
+ 'HAVE_CONNECT': 1,
  'HAVE_COPY_FILE_RANGE': 0,
  'HAVE_CRYPT_H': 0,
  'HAVE_CRYPT_R': 0,
@@ -128,9 +147,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_TYPEAHEAD': 1,
  'HAVE_CURSES_USE_ENV': 1,
  'HAVE_CURSES_WCHGAT': 1,
- 'HAVE_DECL_ISFINITE': 1,
- 'HAVE_DECL_ISINF': 1,
- 'HAVE_DECL_ISNAN': 1,
+ 'HAVE_DB_H': 1,
  'HAVE_DECL_RTLD_DEEPBIND': 0,
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
@@ -149,6 +166,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
+ 'HAVE_DUP': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 0,
  'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
@@ -175,9 +193,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FDOPENDIR': 1,
  'HAVE_FDWALK': 0,
  'HAVE_FEXECVE': 0,
- 'HAVE_FINITE': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
+ 'HAVE_FORK1': 0,
  'HAVE_FORKPTY': 1,
  'HAVE_FPATHCONF': 1,
  'HAVE_FSEEK64': 0,
@@ -193,23 +211,31 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FUTIMES': 1,
  'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
- 'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GDBM_DASH_NDBM_H': 0,
+ 'HAVE_GDBM_H': 0,
+ 'HAVE_GDBM_NDBM_H': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
+ 'HAVE_GETEGID': 1,
  'HAVE_GETENTROPY': 0,
+ 'HAVE_GETEUID': 1,
+ 'HAVE_GETGID': 1,
+ 'HAVE_GETGRGID': 1,
  'HAVE_GETGRGID_R': 1,
  'HAVE_GETGRNAM_R': 1,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
+ 'HAVE_GETHOSTBYADDR': 1,
  'HAVE_GETHOSTBYNAME': 1,
  'HAVE_GETHOSTBYNAME_R': 0,
  'HAVE_GETHOSTBYNAME_R_3_ARG': 0,
  'HAVE_GETHOSTBYNAME_R_5_ARG': 0,
  'HAVE_GETHOSTBYNAME_R_6_ARG': 0,
+ 'HAVE_GETHOSTNAME': 1,
  'HAVE_GETITIMER': 1,
  'HAVE_GETLOADAVG': 1,
  'HAVE_GETLOGIN': 1,
@@ -219,26 +245,34 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETPGID': 1,
  'HAVE_GETPGRP': 1,
  'HAVE_GETPID': 1,
+ 'HAVE_GETPPID': 1,
  'HAVE_GETPRIORITY': 1,
+ 'HAVE_GETPROTOBYNAME': 1,
  'HAVE_GETPWENT': 1,
  'HAVE_GETPWNAM_R': 1,
+ 'HAVE_GETPWUID': 1,
  'HAVE_GETPWUID_R': 1,
  'HAVE_GETRANDOM': 0,
  'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 0,
  'HAVE_GETRESUID': 0,
+ 'HAVE_GETRUSAGE': 1,
+ 'HAVE_GETSERVBYNAME': 1,
+ 'HAVE_GETSERVBYPORT': 1,
  'HAVE_GETSID': 1,
+ 'HAVE_GETSOCKNAME': 1,
  'HAVE_GETSPENT': 0,
  'HAVE_GETSPNAM': 0,
+ 'HAVE_GETUID': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
  'HAVE_HTOLE64': 0,
- 'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
  'HAVE_IF_NAMEINDEX': 1,
  'HAVE_INET_ATON': 1,
+ 'HAVE_INET_NTOA': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
  'HAVE_INTTYPES_H': 1,
@@ -252,16 +286,19 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
- 'HAVE_LGAMMA': 1,
+ 'HAVE_LIBB2': 0,
+ 'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
+ 'HAVE_LIBGDBM_COMPAT': 0,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 1,
+ 'HAVE_LIBNDBM': 0,
  'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
+ 'HAVE_LIBSQLITE3': 1,
  'HAVE_LIBUTIL_H': 0,
- 'HAVE_LIBUUID': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_AUXVEC_H': 0,
@@ -271,19 +308,24 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 0,
+ 'HAVE_LINUX_LIMITS_H': 0,
  'HAVE_LINUX_MEMFD_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_QRTR_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
+ 'HAVE_LINUX_SOUNDCARD_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LINUX_VM_SOCKETS_H': 0,
  'HAVE_LINUX_WAIT_H': 0,
+ 'HAVE_LISTEN': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
+ 'HAVE_LOGIN_TTY': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LSTAT': 1,
  'HAVE_LUTIMES': 1,
+ 'HAVE_LZMA_H': 0,
  'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
@@ -298,16 +340,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 0,
+ 'HAVE_NANOSLEEP': 1,
  'HAVE_NCURSES_H': 1,
+ 'HAVE_NDBM_H': 1,
  'HAVE_NDIR_H': 0,
+ 'HAVE_NETCAN_CAN_H': 0,
+ 'HAVE_NETDB_H': 1,
+ 'HAVE_NETINET_IN_H': 1,
  'HAVE_NETPACKET_PACKET_H': 0,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
  'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
+ 'HAVE_OPENDIR': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
+ 'HAVE_PIPE': 1,
  'HAVE_PIPE2': 0,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
@@ -329,6 +378,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
+ 'HAVE_PTHREAD_STUBS': 0,
  'HAVE_PTY_H': 0,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 0,
@@ -337,16 +387,18 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
+ 'HAVE_RECVFROM': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
+ 'HAVE_RL_COMPDISP_FUNC_T': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
- 'HAVE_ROUND': 1,
+ 'HAVE_RPC_RPC_H': 1,
  'HAVE_RTPSPAWN': 0,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -360,12 +412,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SEM_TIMEDWAIT': 0,
  'HAVE_SEM_UNLINK': 1,
  'HAVE_SENDFILE': 1,
+ 'HAVE_SENDTO': 1,
  'HAVE_SETEGID': 1,
  'HAVE_SETEUID': 1,
  'HAVE_SETGID': 1,
  'HAVE_SETGROUPS': 1,
  'HAVE_SETHOSTNAME': 1,
  'HAVE_SETITIMER': 1,
+ 'HAVE_SETJMP_H': 1,
  'HAVE_SETLOCALE': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
@@ -375,11 +429,13 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SETRESUID': 0,
  'HAVE_SETREUID': 1,
  'HAVE_SETSID': 1,
+ 'HAVE_SETSOCKOPT': 1,
  'HAVE_SETUID': 1,
  'HAVE_SETVBUF': 1,
  'HAVE_SHADOW_H': 0,
  'HAVE_SHM_OPEN': 1,
  'HAVE_SHM_UNLINK': 1,
+ 'HAVE_SHUTDOWN': 1,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
  'HAVE_SIGFILLSET': 1,
@@ -395,6 +451,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_ALG': 0,
  'HAVE_SOCKADDR_SA_LEN': 1,
  'HAVE_SOCKADDR_STORAGE': 1,
+ 'HAVE_SOCKET': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
  'HAVE_SPLICE': 0,
@@ -426,6 +483,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYNC': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
+ 'HAVE_SYSLOG_H': 1,
+ 'HAVE_SYSTEM': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
  'HAVE_SYS_AUXV_H': 0,
  'HAVE_SYS_BSDTTY_H': 0,
@@ -452,6 +511,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 0,
  'HAVE_SYS_SOCKET_H': 1,
+ 'HAVE_SYS_SOUNDCARD_H': 0,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
  'HAVE_SYS_SYSCALL_H': 1,
@@ -471,7 +531,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TEMPNAM': 1,
  'HAVE_TERMIOS_H': 1,
  'HAVE_TERM_H': 1,
- 'HAVE_TGAMMA': 1,
  'HAVE_TIMEGM': 1,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
@@ -479,8 +538,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
+ 'HAVE_TTYNAME': 1,
  'HAVE_TZNAME': 0,
- 'HAVE_UCS4_TCL': 0,
+ 'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
@@ -489,12 +549,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UTIMENSAT': 0,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UTMP_H': 1,
  'HAVE_UUID_CREATE': 0,
  'HAVE_UUID_ENC_BE': 0,
  'HAVE_UUID_GENERATE_TIME_SAFE': 0,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
  'HAVE_VFORK': 1,
+ 'HAVE_WAIT': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -507,43 +569,55 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
+ 'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
+ 'HOSTRUNNER': '',
  'HOST_GNU_TYPE': 'x86_64-apple-darwin14.5.0',
- 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include /opt/local/Library/Frameworks/Python.framework/Versions/3.10/include /opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10 /opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10',
- 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include',
- 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10',
+ 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/include /opt/local/Library/Frameworks/Python.framework/Versions/3.11/include /opt/local/Library/Frameworks/Python.framework/Versions/3.11/include/python3.11 /opt/local/Library/Frameworks/Python.framework/Versions/3.11/include/python3.11',
+ 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/include',
+ 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/include/python3.11',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'Python.framework/Versions/3.10/Python',
+ 'INSTSONAME': 'Python.framework/Versions/3.11/Python',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': '/usr/bin/clang++ -bundle -undefined dynamic_lookup',
  'LDFLAGS': '  -L/opt/local/lib -Wl,-headerpad_max_install_names  ',
- 'LDLIBRARY': 'Python.framework/Versions/3.10/Python',
+ 'LDLIBRARY': 'Python.framework/Versions/3.11/Python',
  'LDLIBRARYDIR': '',
  'LDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup   -L/opt/local/lib -Wl,-headerpad_max_install_names  ',
- 'LDVERSION': '3.10',
+ 'LDVERSION': '3.11',
  'LIBC': '',
- 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
- 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib',
+ 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11',
+ 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib',
+ 'LIBEXPAT_A': 'Modules/expat/libexpat.a',
+ 'LIBEXPAT_CFLAGS': '-fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c11 -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include',
+ 'LIBEXPAT_HEADERS': '\\',
+ 'LIBEXPAT_OBJS': '\\',
  'LIBFFI_INCLUDEDIR': '/opt/local/include',
  'LIBM': '',
+ 'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
+ 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DUNIVERSAL=1 -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c11 -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include',
+ 'LIBMPDEC_HEADERS': '\\',
+ 'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/pkgconfig',
- 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/config-3.10-darwin',
+ 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/pkgconfig',
+ 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11/config-3.11-darwin',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.10.a',
- 'LIBRARY_DEPS': 'libpython3.10.a Python.framework/Versions/3.10/Python',
+ 'LIBRARY': 'libpython3.11.a',
+ 'LIBRARY_DEPS': 'libpython3.11.a Python.framework/Versions/3.11/Python',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-ldl   -framework CoreFoundation',
+ 'LIBS': ' -ldl  -framework CoreFoundation',
  'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': '/usr/bin/clang',
- 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/config-3.10-darwin -lpython3.10 -ldl -framework CoreFoundation',
+ 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11/config-3.11-darwin -lpython3.11 -ldl -framework CoreFoundation',
+ 'LINK_PYTHON_DEPS': 'libpython3.11.a Python.framework/Versions/3.11/Python',
+ 'LINK_PYTHON_OBJS': '',
  'LIPO_32BIT_FLAGS': '-extract i386',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
@@ -553,19 +627,177 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'darwin',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
+ 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11',
  'MACOSX_DEPLOYMENT_TARGET': '10.10',
  'MAINCC': '/usr/bin/clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/share/man',
+ 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/share/man',
  'MKDIR_P': './install-sh -c -d',
- 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  _operator  _collections  _abc  itertools  atexit  _signal  _stat  time  _thread  _locale  _io  faulthandler  _tracemalloc  _symtable  xxsubtype',
+ 'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  _codecs  _collections  errno  _io  itertools  _sre  _thread  time  _weakref  _abc  _functools  _locale  _operator  _stat  _symtable  pwd  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/_operator.o  Modules/_collectionsmodule.o  Modules/_abc.o  Modules/itertoolsmodule.o  Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  Modules/timemodule.o  Modules/_threadmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  Modules/_tracemalloc.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  Modules/posixmodule.o  Modules/signalmodule.o  Modules/_tracemalloc.o  Modules/_codecsmodule.o  Modules/_collectionsmodule.o  Modules/errnomodule.o  Modules/_io/_iomodule.o Modules/_io/iobase.o Modules/_io/fileio.o Modules/_io/bytesio.o Modules/_io/bufferedio.o Modules/_io/textio.o Modules/_io/stringio.o  Modules/itertoolsmodule.o  Modules/_sre/sre.o  Modules/_threadmodule.o  Modules/timemodule.o  Modules/_weakref.o  Modules/_abc.o  Modules/_functoolsmodule.o  Modules/_localemodule.o  Modules/_operator.o  Modules/_stat.o  Modules/symtablemodule.o  Modules/pwdmodule.o  Modules/xxsubtype.o',
+ 'MODSHARED_NAMES': '',
+ 'MODULE_ARRAY_STATE': 'yes',
+ 'MODULE_ATEXIT_LDFLAGS': '',
+ 'MODULE_AUDIOOP_LDFLAGS': '',
+ 'MODULE_AUDIOOP_STATE': 'yes',
+ 'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32 -I/opt/local/include',
+ 'MODULE_BINASCII_LDFLAGS': '-L/opt/local/lib -lz',
+ 'MODULE_BINASCII_STATE': 'yes',
+ 'MODULE_CMATH_DEPS': './Modules/_math.h',
+ 'MODULE_CMATH_LDFLAGS': '',
+ 'MODULE_CMATH_STATE': 'yes',
+ 'MODULE_ERRNO_LDFLAGS': '',
+ 'MODULE_FAULTHANDLER_LDFLAGS': '',
+ 'MODULE_FCNTL_LDFLAGS': '',
+ 'MODULE_FCNTL_STATE': 'yes',
+ 'MODULE_GRP_STATE': 'yes',
+ 'MODULE_ITERTOOLS_LDFLAGS': '',
+ 'MODULE_MATH_DEPS': './Modules/_math.h',
+ 'MODULE_MATH_LDFLAGS': '',
+ 'MODULE_MATH_STATE': 'yes',
+ 'MODULE_MMAP_STATE': 'yes',
+ 'MODULE_NIS_CFLAGS': '',
+ 'MODULE_NIS_LDFLAGS': '',
+ 'MODULE_NIS_STATE': 'yes',
  'MODULE_OBJS': '\\',
+ 'MODULE_OSSAUDIODEV_STATE': 'n/a',
+ 'MODULE_POSIX_LDFLAGS': '',
+ 'MODULE_PWD_LDFLAGS': '',
+ 'MODULE_PWD_STATE': 'yes',
+ 'MODULE_PYEXPAT_CFLAGS': '',
+ 'MODULE_PYEXPAT_DEPS': '',
+ 'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
+ 'MODULE_PYEXPAT_STATE': 'yes',
+ 'MODULE_RESOURCE_STATE': 'yes',
+ 'MODULE_SELECT_STATE': 'yes',
+ 'MODULE_SPWD_STATE': 'n/a',
+ 'MODULE_SYSLOG_STATE': 'yes',
+ 'MODULE_TERMIOS_STATE': 'yes',
+ 'MODULE_TIME_LDFLAGS': '',
+ 'MODULE_TIME_STATE': 'yes',
+ 'MODULE_UNICODEDATA_DEPS': './Modules/unicodedata_db.h ./Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_STATE': 'yes',
+ 'MODULE_XXLIMITED_35_STATE': 'yes',
+ 'MODULE_XXLIMITED_STATE': 'yes',
+ 'MODULE_XXSUBTYPE_LDFLAGS': '',
+ 'MODULE_ZLIB_CFLAGS': '-I/opt/local/include',
+ 'MODULE_ZLIB_LDFLAGS': '-L/opt/local/lib -lz',
+ 'MODULE_ZLIB_STATE': 'yes',
+ 'MODULE__ABC_LDFLAGS': '',
+ 'MODULE__ASYNCIO_STATE': 'yes',
+ 'MODULE__BISECT_STATE': 'yes',
+ 'MODULE__BLAKE2_CFLAGS': '',
+ 'MODULE__BLAKE2_DEPS': './Modules/_blake2/impl/blake2-config.h ./Modules/_blake2/impl/blake2-impl.h ./Modules/_blake2/impl/blake2.h ./Modules/_blake2/impl/blake2b-load-sse2.h ./Modules/_blake2/impl/blake2b-load-sse41.h ./Modules/_blake2/impl/blake2b-ref.c ./Modules/_blake2/impl/blake2b-round.h ./Modules/_blake2/impl/blake2b.c ./Modules/_blake2/impl/blake2s-load-sse2.h ./Modules/_blake2/impl/blake2s-load-sse41.h ./Modules/_blake2/impl/blake2s-load-xop.h ./Modules/_blake2/impl/blake2s-ref.c ./Modules/_blake2/impl/blake2s-round.h ./Modules/_blake2/impl/blake2s.c ./Modules/_blake2/blake2module.h ./Modules/hashlib.h',
+ 'MODULE__BLAKE2_LDFLAGS': '',
+ 'MODULE__BLAKE2_STATE': 'yes',
+ 'MODULE__BZ2_CFLAGS': '',
+ 'MODULE__BZ2_LDFLAGS': '-lbz2',
+ 'MODULE__BZ2_STATE': 'yes',
+ 'MODULE__CODECS_CN_STATE': 'yes',
+ 'MODULE__CODECS_HK_STATE': 'yes',
+ 'MODULE__CODECS_ISO2022_STATE': 'yes',
+ 'MODULE__CODECS_JP_STATE': 'yes',
+ 'MODULE__CODECS_KR_STATE': 'yes',
+ 'MODULE__CODECS_LDFLAGS': '',
+ 'MODULE__CODECS_TW_STATE': 'yes',
+ 'MODULE__COLLECTIONS_LDFLAGS': '',
+ 'MODULE__CONTEXTVARS_STATE': 'yes',
+ 'MODULE__CRYPT_CFLAGS': '',
+ 'MODULE__CRYPT_LDFLAGS': '',
+ 'MODULE__CRYPT_STATE': 'yes',
+ 'MODULE__CSV_STATE': 'yes',
+ 'MODULE__CTYPES_DEPS': './Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
+ 'MODULE__CTYPES_TEST_STATE': 'yes',
+ 'MODULE__DATETIME_LDFLAGS': '',
+ 'MODULE__DATETIME_STATE': 'yes',
+ 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DUNIVERSAL=1',
+ 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ Modules/_decimal/libmpdec/libmpdec.a',
+ 'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'MODULE__DECIMAL_STATE': 'yes',
+ 'MODULE__ELEMENTTREE_CFLAGS': '',
+ 'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_STATE': 'yes',
+ 'MODULE__FUNCTOOLS_LDFLAGS': '',
+ 'MODULE__GDBM_STATE': 'missing',
+ 'MODULE__HASHLIB_CFLAGS': '-I/opt/local/libexec/openssl3/include',
+ 'MODULE__HASHLIB_DEPS': './Modules/hashlib.h',
+ 'MODULE__HASHLIB_LDFLAGS': '-L/opt/local/libexec/openssl3/lib   -lcrypto',
+ 'MODULE__HASHLIB_STATE': 'yes',
+ 'MODULE__HEAPQ_STATE': 'yes',
+ 'MODULE__IO_CFLAGS': '-I./Modules/_io',
+ 'MODULE__IO_DEPS': './Modules/_io/_iomodule.h',
+ 'MODULE__IO_LDFLAGS': '',
+ 'MODULE__IO_STATE': 'yes',
+ 'MODULE__JSON_STATE': 'yes',
+ 'MODULE__LOCALE_LDFLAGS': '',
+ 'MODULE__LSPROF_STATE': 'yes',
+ 'MODULE__LZMA_CFLAGS': '-I/opt/local/include',
+ 'MODULE__LZMA_LDFLAGS': '-L/opt/local/lib -llzma',
+ 'MODULE__LZMA_STATE': 'yes',
+ 'MODULE__MD5_DEPS': './Modules/hashlib.h',
+ 'MODULE__MD5_STATE': 'yes',
+ 'MODULE__MULTIBYTECODEC_STATE': 'yes',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I./Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_STATE': 'yes',
+ 'MODULE__OPCODE_STATE': 'yes',
+ 'MODULE__OPERATOR_LDFLAGS': '',
+ 'MODULE__PICKLE_STATE': 'yes',
+ 'MODULE__POSIXSHMEM_CFLAGS': '-I./Modules/_multiprocessing',
+ 'MODULE__POSIXSHMEM_LDFLAGS': '',
+ 'MODULE__POSIXSHMEM_STATE': 'yes',
+ 'MODULE__POSIXSUBPROCESS_STATE': 'yes',
+ 'MODULE__QUEUE_STATE': 'yes',
+ 'MODULE__RANDOM_STATE': 'yes',
+ 'MODULE__SCPROXY_LDFLAGS': '-framework SystemConfiguration -framework CoreFoundation',
+ 'MODULE__SCPROXY_STATE': 'yes',
+ 'MODULE__SHA1_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA1_STATE': 'yes',
+ 'MODULE__SHA256_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA256_STATE': 'yes',
+ 'MODULE__SHA3_DEPS': './Modules/_sha3/sha3.c ./Modules/_sha3/sha3.h ./Modules/hashlib.h',
+ 'MODULE__SHA3_STATE': 'yes',
+ 'MODULE__SHA512_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA512_STATE': 'yes',
+ 'MODULE__SIGNAL_LDFLAGS': '',
+ 'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h ./Modules/getaddrinfo.c ./Modules/getnameinfo.c',
+ 'MODULE__SOCKET_STATE': 'yes',
+ 'MODULE__SQLITE3_CFLAGS': '-I/opt/local/include -I./Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': './Modules/_sqlite/connection.h ./Modules/_sqlite/cursor.h ./Modules/_sqlite/microprotocols.h ./Modules/_sqlite/module.h ./Modules/_sqlite/prepare_protocol.h ./Modules/_sqlite/row.h ./Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_LDFLAGS': '-L/opt/local/lib -lsqlite3',
+ 'MODULE__SQLITE3_STATE': 'yes',
+ 'MODULE__SRE_LDFLAGS': '',
+ 'MODULE__SSL_CFLAGS': '-I/opt/local/libexec/openssl3/include',
+ 'MODULE__SSL_DEPS': './Modules/_ssl.h ./Modules/_ssl/cert.c ./Modules/_ssl/debughelpers.c ./Modules/_ssl/misc.c ./Modules/_ssl_data.h ./Modules/_ssl_data_111.h ./Modules/_ssl_data_300.h ./Modules/socketmodule.h',
+ 'MODULE__SSL_LDFLAGS': '-L/opt/local/libexec/openssl3/lib  -lssl -lcrypto',
+ 'MODULE__SSL_STATE': 'yes',
+ 'MODULE__STATISTICS_LDFLAGS': '',
+ 'MODULE__STATISTICS_STATE': 'yes',
+ 'MODULE__STAT_LDFLAGS': '',
+ 'MODULE__STRUCT_STATE': 'yes',
+ 'MODULE__SYMTABLE_LDFLAGS': '',
+ 'MODULE__TESTBUFFER_STATE': 'yes',
+ 'MODULE__TESTCAPI_DEPS': './Modules/testcapi_long.h',
+ 'MODULE__TESTCAPI_STATE': 'yes',
+ 'MODULE__TESTCLINIC_STATE': 'yes',
+ 'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
+ 'MODULE__TESTINTERNALCAPI_STATE': 'yes',
+ 'MODULE__TESTMULTIPHASE_STATE': 'yes',
+ 'MODULE__THREAD_LDFLAGS': '',
+ 'MODULE__TKINTER_STATE': 'missing',
+ 'MODULE__TRACEMALLOC_LDFLAGS': '',
+ 'MODULE__TYPING_STATE': 'yes',
+ 'MODULE__UUID_CFLAGS': '',
+ 'MODULE__UUID_LDFLAGS': '',
+ 'MODULE__UUID_STATE': 'yes',
+ 'MODULE__WEAKREF_LDFLAGS': '',
+ 'MODULE__XXSUBINTERPRETERS_STATE': 'yes',
+ 'MODULE__XXTESTFUZZ_STATE': 'yes',
+ 'MODULE__ZONEINFO_STATE': 'yes',
  'MULTIARCH': 'darwin',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"darwin\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
@@ -605,39 +837,46 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '/opt/local/Library/Frameworks',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_BUILD_DEPS': 'python',
+ 'PYTHON_FOR_FREEZE': './_bootstrap_python',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os  ',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c11 -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include -DPy_BUILD_CORE_BUILTIN',
+ 'PY_CFLAGS': '-fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os  ',
+ 'PY_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include -DPy_BUILD_CORE',
+ 'PY_CORE_CFLAGS': '-fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c11 -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '  -L/opt/local/lib -Wl,-headerpad_max_install_names  ',
  'PY_CPPFLAGS': '-I. -I./Include -I/opt/local/include',
  'PY_ENABLE_SHARED': 0,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '  -L/opt/local/lib -Wl,-headerpad_max_install_names  ',
  'PY_LDFLAGS_NODIST': '',
+ 'PY_LDFLAGS_NOLTO': '  -L/opt/local/lib -Wl,-headerpad_max_install_names  ',
+ 'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
+ 'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include',
+ 'PY_STDMODULE_CFLAGS': '-fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall   -pipe -Os   -std=c11 -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include',
+ 'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
  'Py_HASH_ALGORITHM': 0,
+ 'Py_STATS': 0,
+ 'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19',
- 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib',
+ 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python311-b83b7169/work/Python-3.11.14',
+ 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
- 'SHLIBS': '-ldl   -framework CoreFoundation',
+ 'SHLIBS': ' -ldl  -framework CoreFoundation',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -658,8 +897,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 4,
- 'SOABI': 'cpython-310-darwin',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-311-darwin',
+ 'SRCDIRS': 'Modules   Modules/_blake2   Modules/_ctypes   Modules/_decimal   Modules/_decimal/libmpdec   Modules/_io   Modules/_multiprocessing   Modules/_sha3   Modules/_sqlite   Modules/_sre   Modules/_xxtestfuzz   Modules/cjkcodecs   Modules/expat   Objects   Parser   Programs   Python   Python/frozen_modules   Python/deepfreeze',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
@@ -669,13 +908,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19 ./python',
+ 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python311-b83b7169/work/Python-3.11.14 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19 ./python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python311-b83b7169/work/Python-3.11.14 ./python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -688,7 +925,9 @@ build_time_vars = {'ABIFLAGS': '',
  'UNIVERSALSDK': '/',
  'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.10',
+ 'VERSION': '3.11',
+ 'WASM_ASSETS_DIR': './opt/local/Library/Frameworks/Python.framework/Versions/3.11',
+ 'WASM_STDLIB': './opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/python3.11/os.py',
  'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -696,15 +935,16 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_DTRACE': 0,
  'WITH_DYLD': 1,
  'WITH_EDITLINE': 1,
+ 'WITH_FREELISTS': 1,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 1,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19',
- 'abs_srcdir': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19',
- 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/share',
- 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10',
- 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10',
+ 'abs_builddir': '/opt/local/var/macports/build/python311-b83b7169/work/Python-3.11.14',
+ 'abs_srcdir': '/opt/local/var/macports/build/python311-b83b7169/work/Python-3.11.14',
+ 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11/share',
+ 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11',
+ 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.11',
  'srcdir': '.'}
